@@ -50,6 +50,8 @@ RadialMap::Widget::Widget(QWidget *parent, bool isSummary)
 
     connect(this, &Widget::folderCreated, this, &Widget::sendFakeMouseEvent);
     connect(&m_timer, &QTimer::timeout, this, &Widget::resizeTimeout);
+    m_tooltip.setFrameShape(QFrame::StyledPanel);
+    m_tooltip.setWindowFlags(Qt::ToolTip | Qt::WindowTransparentForInput);
 }
 
 RadialMap::Widget::~Widget()
@@ -65,7 +67,7 @@ QString RadialMap::Widget::path() const
 
 QUrl RadialMap::Widget::url(File const * const file) const
 {
-    return QUrl::fromLocalFile (file ? file->fullPath() : m_tree->fullPath());
+    return QUrl::fromUserInput(file ? file->fullPath() : m_tree->fullPath());
 }
 
 void RadialMap::Widget::invalidate()
@@ -78,6 +80,9 @@ void RadialMap::Widget::invalidate()
         //disable mouse tracking
         setMouseTracking(false);
 
+        // Get this before reseting m_tree below
+        QUrl invalidatedUrl(url());
+
         //ensure this class won't think we have a map still
         m_tree  = 0;
         m_focus = 0;
@@ -91,7 +96,7 @@ void RadialMap::Widget::invalidate()
         update();
 
         //tell rest of Filelight
-        emit invalidated(url());
+        emit invalidated(invalidatedUrl);
     }
 }
 
